@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/twm/add_window.c,v 1.15 2006/01/09 15:00:53 dawes Exp $ */
+/* $XFree86: xc/programs/twm/add_window.c,v 1.16 2006/12/10 15:58:34 tsi Exp $ */
 /*****************************************************************************/
 /*
 
@@ -179,7 +179,7 @@ IconMgr *iconp;
     char *name;
 
 #ifdef DEBUG
-    fprintf(stderr, "AddWindow: w = 0x%x\n", w);
+    fprintf(stderr, "AddWindow: w = 0x%lx\n", (unsigned long)w);
 #endif
 
     /* allocate space for the twm window */
