@@ -1,4 +1,3 @@
-/* $Xorg: dm.c,v 1.5 2001/02/09 02:05:40 xorgcvs Exp $ */
 /*
 
 Copyright 1988, 1998  The Open Group
@@ -26,7 +25,7 @@ other dealings in this Software without prior written authorization
 from The Open Group.
 
 */
-/* $XFree86: xc/programs/xdm/dm.c,v 3.24 2004/01/10 21:26:29 herrb Exp $ */
+/* $XFree86: xc/programs/xdm/dm.c,v 3.26 2006/01/09 15:01:03 dawes Exp $ */
 
 /*
  * xdm - display manager daemon
@@ -73,7 +72,7 @@ from The Open Group.
 #endif
 
 
-#if defined(SVR4) && !defined(SCO) && !defined(sun)
+#if defined(SVR4) && !defined(__SCO__) && !defined(sun)
 extern FILE    *fdopen();
 #endif
 
